@@ -1,6 +1,6 @@
 from enum import auto
 
-from pydantic import BaseModel, constr
+from pydantic import BaseModel, Field
 
 from stac_pydantic.utils import AutoValueEnum
 
@@ -15,5 +15,5 @@ class SortExtension(BaseModel):
     https://github.com/radiantearth/stac-api-spec/tree/master/extensions/sort#sort-api-extension
     """
 
-    field: constr(min_length=1)
+    field: str = Field(..., alias="field", min_length=1)
     direction: SortDirections
