@@ -1,6 +1,9 @@
+import pytest
+
 from stac_pydantic.scripts.cli import app
 
 
+@pytest.mark.network
 def test_valid_stac_item(cli_runner):
     result = cli_runner.invoke(
         app,
